## How to be a contributor to this project

### Are you submitting a pull request?

* Make sure to fill out an issue for your PR, so that we have traceability as to what you are trying to fix,
versus how you fixed it.
* Spaces (not tabs), and 2 of them, that's what we like. Set your code style :)
* Sign the [Sonatype CLA](https://sonatypecla.herokuapp.com/sign-cla)
* Try to fix one thing per pull request! Many people work on this code, so the more focused your changes are, the less
of a headache other people will have when they merge their work in.
* Ensure your Pull Request passes tests either locally or via TravisCI (it will run automatically on your PR)
* Make sure to add yourself or your organization to CONTRIBUTORS.md as a part of your PR, if you are new to the project!
* If you're stuck, ask our [gitter channel](https://gitter.im/sonatype/nexus-developers)! There are a number of
experienced programmers who are happy to help with learning and troubleshooting.

### Are you new and looking to dive in?

* Check our issues to see if there is something you can dive in to.
* Come hang out with us at our [gitter channel](https://gitter.im/sonatype/nexus-developers).
